==> module-database-postgresql-1.0.10-sources.jar: be/yildizgames/module/database/postgresql/PostgresqlQueryBuilder.java <==
/*
 * This file is part of the Yildiz-Engine project, licenced under the MIT License  (MIT)
 *
 *  Copyright (c) 2019 Grégory Van den Borre
 *
 *  More infos available: https://engine.yildiz-games.be
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 *  documentation files (the "Software"), to deal in the Software without restriction, including without
 *  limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is furnished to do so,
 *  subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all copies or substantial
 *  portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 *  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 *  OR COPYRIGHT  HOLDERS BE LIABLE FOR ANY CLAIM,
 *  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  SOFTWARE.
 *
 */
package be.yildizgames.module.database.postgresql;

import be.yildizgames.module.database.QueryBuilder;

/**
 * @author Grégory Van den Borre
 */
class PostgresqlQueryBuilder extends QueryBuilder {

    PostgresqlQueryBuilder(String table) {
        super(table);
    }

    @Override
    public QueryBuilder selectAllFrom() {
        this.append("SELECT * FROM " + this.table + " ");
        return this;
    }

    @Override
    public final QueryBuilder limit(int number) {
        this.append("LIMIT " + number + " ");
        return this;
    }

    @Override
    public QueryBuilder merge(String s, String... strings) {
        return null;
    }

    @Override
    public final QueryBuilder selectAllFrom(String schema) {
        return this.selectAllFrom(schema + "." + this.table);
    }
}

==> module-database-postgresql-1.0.13-sources.jar: be/yildizgames/module/database/postgresql/PostgresqlQueryBuilder.java <==
/*
 * This file is part of the Yildiz-Engine project, licenced under the MIT License  (MIT)
 *
 *  Copyright (c) 2019 Grégory Van den Borre
 *
 *  More infos available: https://engine.yildiz-games.be
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 *  documentation files (the "Software"), to deal in the Software without restriction, including without
 *  limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is furnished to do so,
 *  subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in all copies or substantial
 *  portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 *  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 *  OR COPYRIGHT  HOLDERS BE LIABLE FOR ANY CLAIM,
 *  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  SOFTWARE.
 *
 */
package be.yildizgames.module.database.postgresql;

import be.yildizgames.module.database.QueryBuilder;
import be.yildizgames.module.database.TableSchema;

/**
 * @author Grégory Van den Borre
 */
class PostgresqlQueryBuilder extends QueryBuilder {

    PostgresqlQueryBuilder(TableSchema table) {
        super(table);
    }

    @Override
    public QueryBuilder selectAllFrom() {
        this.append("SELECT * FROM " + this.table + " ");
        return this;
    }

    @Override
    public QueryBuilder select(String... columns) {
        var c = String.join(", ", columns);
        this.append("SELECT " + c + " FROM " + table.getTableName() + " ");
        return this;
    }

    @Override
    public final QueryBuilder limit(int number) {
        this.append("LIMIT " + number + " ");
        return this;
    }

    @Override
    public QueryBuilder merge(String s, String... strings) {
        return null;
    }

}
